==> eiffelstudio-16.05.tar: F_code/C68/re3389.c <==
/*
 * Code for class RESIZABLE [NATURAL_8]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "re3389.h"
#include "eif_helpers.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {RESIZABLE}.additional_space */
EIF_INTEGER_32 F800_8515 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R7727[Dtype(Current)-826])(Current);
	Result = eif_max_int32 ((EIF_INTEGER_32) (ti4_1 / ((EIF_INTEGER_32) 2L)),((EIF_INTEGER_32) 5L));
	RTLE;
	return Result;
}

/* {RESIZABLE}.automatic_grow */
void F800_8517 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R7727[dtype-826])(Current);
	{
		/* INLINED CODE (additional_space) */
		ti4_2 = (EIF_INTEGER_32)  0;
		ti4_3 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R7727[Dtype(Current)-826])(Current);
		ti4_2 = eif_max_int32 ((EIF_INTEGER_32) (ti4_3 / ((EIF_INTEGER_32) 2L)),((EIF_INTEGER_32) 5L));
		/* END INLINED CODE */
	}
	ti4_3 = ti4_2;
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R7733[dtype-826])(Current, (EIF_INTEGER_32) (ti4_1 + ti4_3));
	RTLE;
}

void EIF_Minit3389 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-25.12.9.8922.tar: F_code/C68/re3389.c <==
/*
 * Code for class RESIZABLE [NATURAL_64]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "re3389.h"
#include "eif_helpers.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {RESIZABLE}.additional_space */
EIF_INTEGER_32 F1522_16242 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R13990[Dtype(Current)-1555])(Current);
	Result = eif_max_int32 ((EIF_INTEGER_32) (ti4_1 / ((EIF_INTEGER_32) 2L)),((EIF_INTEGER_32) 5L));
	RTLE;
	return Result;
}

/* {RESIZABLE}.automatic_grow */
void F1522_16244 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R13990[dtype-1555])(Current);
	{
		/* INLINED CODE (RESIZABLE.additional_space) */
		ti4_2 = (EIF_INTEGER_32)  0;
		ti4_3 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R13990[dtype-1555])(Current);
		ti4_2 = eif_max_int32 ((EIF_INTEGER_32) (ti4_3 / ((EIF_INTEGER_32) 2L)),((EIF_INTEGER_32) 5L));
		/* END INLINED CODE */
	}
	ti4_3 = ti4_2;
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R13996[dtype-1555])(Current, (EIF_INTEGER_32) (ti4_1 + ti4_3));
	RTLE;
}

void EIF_Minit3389 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
